@@ -14,11 +14,11 @@ WebService::DataDog::Dashboard - Interface to Dashboard functions in DataDog's A
 
 =head1 VERSION
 
-Version 1.0.0
+Version 1.0.1
 
 =cut
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.1';
 
 
 =head1 SYNOPSIS
@@ -570,58 +570,4 @@ sub _error_checks
 }
 
 
-=head1 AUTHOR
-
-Jennifer Pinkham, C<< <jpinkham at cpan.org> >>.
-
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-WebService-DataDog at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-DataDog>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-	perldoc WebService::DataDog::Dashboard
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WebService-DataDog>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/WebService-DataDog>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/WebService-DataDog>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/WebService-DataDog/>
-
-=back
-
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2013 Jennifer Pinkham.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
-
-=cut
-
-
 1;
